@@ -1,5 +1,5 @@
 package Consul;
-$Consul::VERSION = '0.017';
+$Consul::VERSION = '0.018';
 # ABSTRACT: Client library for consul
 
 use namespace::autoclean;
@@ -513,6 +513,16 @@ Robert Norris <rob@eatenbyagrue.org>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Aran Deltac <bluefeet@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Robert Norris.
